@@ -14,9 +14,6 @@
 # limitations under the License.
 """Version-agnostic Fleet API client."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import collections
 from typing import Generator
@@ -1531,6 +1528,56 @@ class FleetClient(object):
     """Delete a fleet rollout."""
     return self.client.projects_locations_rollouts.Delete(req)
 
+  def CreateRolloutSequence(
+      self, req: types.GkehubProjectsLocationsRolloutSequencesCreateRequest
+  ):
+    """Creates a rollout sequence resource.
+
+    Args:
+      req: An HTTP create rollout sequence request to be sent to the API server.
+
+    Returns:
+      A long-running operation.
+
+    Raises:
+      apitools.base.py.HttpError: if the request returns an HTTP error
+    """
+    return self.client.projects_locations_rolloutSequences.Create(req)
+
+  def DescribeRolloutSequence(
+      self, req: types.GkehubProjectsLocationsRolloutSequencesGetRequest
+  ) -> types.RolloutSequence:
+    """Describes a rollout sequence."""
+    return self.client.projects_locations_rolloutSequences.Get(req)
+
+  def ListRolloutSequences(
+      self,
+      req: types.GkehubProjectsLocationsRolloutSequencesListRequest,
+      page_size=None,
+      limit=None,
+  ) -> types.RolloutSequenceGenerator:
+    """Lists rollout sequences."""
+    return list_pager.YieldFromList(
+        self.client.projects_locations_rolloutSequences,
+        req,
+        field='rolloutSequences',
+        batch_size=page_size,
+        limit=limit,
+        batch_size_attribute='pageSize',
+    )
+
+  def UpdateRolloutSequence(
+      self, req: types.GkehubProjectsLocationsRolloutSequencesPatchRequest
+  ):
+    """Updates a RolloutSequence and returns the long-running operation message."""
+    return self.client.projects_locations_rolloutSequences.Patch(req)
+
+  def DeleteRolloutSequence(
+      self, req: types.GkehubProjectsLocationsRolloutSequencesDeleteRequest
+  ):
+    """Deletes a rollout sequence."""
+    return self.client.projects_locations_rolloutSequences.Delete(req)
+
 
 class OperationClient:
   """Client for the GKE Hub API long-running operations."""
