@@ -14,9 +14,6 @@
 # limitations under the License.
 """Helpers for interacting with the Cloud Dataflow API."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import json
 import os
@@ -446,9 +443,11 @@ class Templates:
   FLEX_TEMPLATE_JAVA11_BASE_IMAGE = _GetBaseImagePath('java11')
   FLEX_TEMPLATE_JAVA17_BASE_IMAGE = _GetBaseImagePath('java17')
   FLEX_TEMPLATE_JAVA21_BASE_IMAGE = _GetBaseImagePath('java21')
+  FLEX_TEMPLATE_JAVA25_BASE_IMAGE = _GetBaseImagePath('java25')
   FLEX_TEMPLATE_JAVA11_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java11', True)
   FLEX_TEMPLATE_JAVA17_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java17', True)
   FLEX_TEMPLATE_JAVA21_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java21', True)
+  FLEX_TEMPLATE_JAVA25_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('java25', True)
   FLEX_TEMPLATE_PYTHON3_BASE_IMAGE = _GetBaseImagePath('python3')
   FLEX_TEMPLATE_GO_BASE_IMAGE = _GetBaseImagePath('go')
   FLEX_TEMPLATE_GO_DISTROLESS_BASE_IMAGE = _GetBaseImagePath('go', True)
@@ -715,12 +714,14 @@ class Templates:
         f'/template/{env["FLEX_TEMPLATE_PYTHON_PY_FILE"]}'
     )
     if 'FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES' in env:
-      env['FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES'] = (
-          f'/template/{env["FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES"]}'
-      )
-      commands.append(
-          f'pip install {env["FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES"]}'
-      )
+      package_list = env['FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES'].split(',')
+      if package_list:
+        packages_path = [f'/template/{package}' for package in package_list]
+        env['FLEX_TEMPLATE_PYTHON_EXTRA_PACKAGES'] = ','.join(packages_path)
+        package_arg = ' '.join(packages_path)
+        commands.append(
+            f'pip install {package_arg}'
+        )
     if 'FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE' in env:
       env['FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE'] = (
           f'/template/{env["FLEX_TEMPLATE_PYTHON_REQUIREMENTS_FILE"]}'
@@ -957,12 +958,16 @@ class Templates:
       return Templates.FLEX_TEMPLATE_JAVA17_BASE_IMAGE
     elif flex_template_base_image == 'JAVA21':
       return Templates.FLEX_TEMPLATE_JAVA21_BASE_IMAGE
+    elif flex_template_base_image == 'JAVA25':
+      return Templates.FLEX_TEMPLATE_JAVA25_BASE_IMAGE
     elif flex_template_base_image == 'JAVA11_DISTROLESS':
       return Templates.FLEX_TEMPLATE_JAVA11_DISTROLESS_BASE_IMAGE
     elif flex_template_base_image == 'JAVA17_DISTROLESS':
       return Templates.FLEX_TEMPLATE_JAVA17_DISTROLESS_BASE_IMAGE
     elif flex_template_base_image == 'JAVA21_DISTROLESS':
       return Templates.FLEX_TEMPLATE_JAVA21_DISTROLESS_BASE_IMAGE
+    elif flex_template_base_image == 'JAVA25_DISTROLESS':
+      return Templates.FLEX_TEMPLATE_JAVA25_DISTROLESS_BASE_IMAGE
     elif flex_template_base_image == 'JAVA8':
       log.warning(
           'JAVA8 is deprecated and redirected to JAVA11. This option '
