@@ -14,9 +14,6 @@
 # limitations under the License.
 """Wrapper for user-visible error exceptions to raise in the CLI."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 from googlecloudsdk.core import exceptions
 
