@@ -14,10 +14,7 @@
 # limitations under the License.
 """Commands for interacting with the Cloud NetApp Files Storage Pool API resource."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
-
+from typing import Any, Dict, Optional
 from apitools.base.py import list_pager
 from googlecloudsdk.api_lib.netapp import constants
 from googlecloudsdk.api_lib.netapp import util as netapp_api_util
@@ -81,24 +78,31 @@ class StoragePoolsClient(object):
         create_op.name, collection=constants.OPERATIONS_COLLECTION)
     return self.WaitForOperation(operation_ref)
 
-  def ParseStoragePoolConfig(self,
-                             name=None,
-                             service_level=None,
-                             network=None,
-                             active_directory=None,
-                             kms_config=None,
-                             enable_ldap=None,
-                             capacity=None,
-                             description=None,
-                             allow_auto_tiering=None,
-                             zone=None,
-                             replica_zone=None,
-                             custom_performance_enabled=None,
-                             total_throughput=None,
-                             total_iops=None,
-                             hot_tier_size=None,
-                             enable_hot_tier_auto_resize=None,
-                             labels=None):
+  def ParseStoragePoolConfig(
+      self,
+      name: Optional[str] = None,
+      service_level: Optional[str] = None,
+      network: Optional[Dict[str, Any]] = None,
+      active_directory: Optional[str] = None,
+      kms_config: Optional[str] = None,
+      enable_ldap: Optional[bool] = None,
+      capacity: Optional[int] = None,
+      description: Optional[str] = None,
+      allow_auto_tiering: Optional[bool] = None,
+      zone: Optional[str] = None,
+      replica_zone: Optional[str] = None,
+      custom_performance_enabled: Optional[bool] = None,
+      total_throughput: Optional[int] = None,
+      total_iops: Optional[int] = None,
+      hot_tier_size: Optional[int] = None,
+      enable_hot_tier_auto_resize: Optional[bool] = None,
+      labels: Optional[Dict[str, str]] = None,
+      unified_pool: Optional[bool] = None,
+      qos_type: Optional[str] = None,
+      storage_pool_type: Optional[str] = None,
+      scale_tier: Optional[str] = None,
+      mode: Optional[str] = None,
+  ):
     """Parses the command line arguments for Create Storage Pool into a config."""
     return self._adapter.ParseStoragePoolConfig(
         name=name,
@@ -117,7 +121,12 @@ class StoragePoolsClient(object):
         total_iops=total_iops,
         hot_tier_size=hot_tier_size,
         enable_hot_tier_auto_resize=enable_hot_tier_auto_resize,
-        labels=labels
+        labels=labels,
+        unified_pool=unified_pool,
+        qos_type=qos_type,
+        storage_pool_type=storage_pool_type,
+        scale_tier=scale_tier,
+        mode=mode,
     )
 
   def ListStoragePools(self, location_ref, limit=None):
@@ -176,7 +185,9 @@ class StoragePoolsClient(object):
                                     total_iops=None,
                                     hot_tier_size=None,
                                     enable_hot_tier_auto_resize=None,
-                                    labels=None):
+                                    qos_type=None,
+                                    labels=None,
+                                    ):
     """Parses updates into a storage pool config.
 
     Args:
@@ -192,6 +203,7 @@ class StoragePoolsClient(object):
       hot_tier_size: int, hot tier size of the storage pool
       enable_hot_tier_auto_resize: bool, whether hot tier auto resize is enabled
       for the storage pool
+      qos_type: qos (quality of service) type of the storage pool
       labels: LabelsValue message, the new labels value, if any.
 
     Returns:
@@ -209,7 +221,8 @@ class StoragePoolsClient(object):
         total_iops=total_iops,
         hot_tier_size=hot_tier_size,
         enable_hot_tier_auto_resize=enable_hot_tier_auto_resize,
-        labels=labels
+        qos_type=qos_type,
+        labels=labels,
     )
     return storage_pool
 
@@ -292,23 +305,28 @@ class StoragePoolsAdapter(object):
 
   def ParseStoragePoolConfig(
       self,
-      name,
-      service_level,
-      network,
-      kms_config,
-      active_directory,
-      enable_ldap,
-      capacity,
-      description,
-      allow_auto_tiering,
-      zone,
-      replica_zone,
-      custom_performance_enabled,
-      total_throughput,
-      total_iops,
-      hot_tier_size,
-      enable_hot_tier_auto_resize,
-      labels,
+      name: Optional[str] = None,
+      service_level: Optional[str] = None,
+      network: Optional[Dict[str, Any]] = None,
+      kms_config: Optional[str] = None,
+      active_directory: Optional[str] = None,
+      enable_ldap: Optional[bool] = None,
+      capacity: Optional[int] = None,
+      description: Optional[str] = None,
+      allow_auto_tiering: Optional[bool] = None,
+      zone: Optional[str] = None,
+      replica_zone: Optional[str] = None,
+      custom_performance_enabled: Optional[bool] = None,
+      total_throughput: Optional[int] = None,
+      total_iops: Optional[int] = None,
+      hot_tier_size: Optional[int] = None,
+      enable_hot_tier_auto_resize: Optional[bool] = None,
+      qos_type: Optional[str] = None,
+      labels: Optional[Dict[str, str]] = None,
+      unified_pool: Optional[bool] = None,
+      storage_pool_type: Optional[str] = None,
+      scale_tier: Optional[str] = None,
+      mode: Optional[str] = None,
   ):
     """Parses the command line arguments for Create Storage Pool into a config.
 
@@ -330,7 +348,12 @@ class StoragePoolsAdapter(object):
       hot_tier_size: Hot tier size of the Storage Pool
       enable_hot_tier_auto_resize: Bool on whether hot tier auto resize is
         enabled
+      qos_type: qos (quality of service) type of the storage pool
       labels: the parsed labels value
+      unified_pool: Bool on whether the Storage Pool is a unified pool
+      storage_pool_type: Type of the Storage Pool
+      scale_tier: Scale tier of the Storage Pool
+      mode: Mode of the Storage Pool - ONTAP or DEFAULT
 
     Returns:
       The configuration that will be used as the request body for creating a
@@ -363,7 +386,17 @@ class StoragePoolsAdapter(object):
       storage_pool.hotTierSizeGib = hot_tier_size
     if enable_hot_tier_auto_resize is not None:
       storage_pool.enableHotTierAutoResize = enable_hot_tier_auto_resize
+    if qos_type is not None:
+      storage_pool.qosType = qos_type
     storage_pool.labels = labels
+    if unified_pool is not None:
+      storage_pool.unifiedPool = unified_pool
+    if storage_pool_type is not None:
+      storage_pool.type = storage_pool_type
+    if scale_tier is not None:
+      storage_pool.scaleTier = scale_tier
+    if mode is not None:
+      storage_pool.mode = mode
     return storage_pool
 
   def ParseUpdatedStoragePoolConfig(
@@ -380,6 +413,7 @@ class StoragePoolsAdapter(object):
       total_iops=None,
       hot_tier_size=None,
       enable_hot_tier_auto_resize=None,
+      qos_type=None,
   ):
     """Parse update information into an updated Storage Pool message."""
     if capacity is not None:
@@ -402,6 +436,8 @@ class StoragePoolsAdapter(object):
       storagepool_config.hotTierSizeGib = hot_tier_size
     if enable_hot_tier_auto_resize is not None:
       storagepool_config.enableHotTierAutoResize = enable_hot_tier_auto_resize
+    if qos_type is not None:
+      storagepool_config.qosType = qos_type
     if labels is not None:
       storagepool_config.labels = labels
     return storagepool_config
