@@ -14,9 +14,8 @@
 # limitations under the License.
 """Client for interacting with Google Cloud Storage using gRPC API."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
+
+import contextlib
 
 from googlecloudsdk.api_lib.storage import cloud_api
 from googlecloudsdk.api_lib.storage import errors as cloud_errors
@@ -57,6 +56,7 @@ class GrpcClientWithJsonFallback(gcs_json_client.JsonClient):
   def __init__(self):
     super(GrpcClientWithJsonFallback, self).__init__()
     self._gapic_client = None
+    self._exit_stack = contextlib.ExitStack()
 
   def _get_gapic_client(self, redact_request_body_reason=None):
     # Not using @property because the side-effect is non-trivial and
@@ -70,8 +70,38 @@ class GrpcClientWithJsonFallback(gcs_json_client.JsonClient):
           attempt_direct_path=True,
           redact_request_body_reason=redact_request_body_reason,
       )
+      self._exit_stack.enter_context(self._gapic_client)
     return self._gapic_client
 
+  def close(self):
+    """Closes the gapic client if it exists."""
+    self._exit_stack.close()
+
+  def get_bucket(
+      self,
+      bucket_name,
+      generation=None,
+      fields_scope=cloud_api.FieldsScope.FULL,
+      soft_deleted=False,
+  ):
+    """See super class."""
+    # TODO(b/324352239): This is a temporary implementation to unblock
+    # direct connectivity diagnostic for Rapid.
+    if generation is not None:
+      raise ValueError('generation is not supported in gRPC API.')
+    if soft_deleted:
+      raise ValueError('soft_deleted is not supported in gRPC API.')
+    if fields_scope != cloud_api.FieldsScope.FULL:
+      raise ValueError('fields_scope is not supported in gRPC API.')
+
+    self._get_gapic_client()
+    metadata = self._gapic_client.storage.get_bucket(
+        self._gapic_client.types.GetBucketRequest(
+            name=grpc_util.get_full_bucket_name(bucket_name),
+        )
+    )
+    return metadata_util.get_bucket_resource_from_metadata(metadata)
+
   def compose_objects(
       self,
       source_resources,
@@ -398,8 +428,8 @@ class GrpcClientWithJsonFallback(gcs_json_client.JsonClient):
       destination_resource,
       request_config,
       posix_to_set=None,
-      serialization_data=None,
       source_resource=None,
+      serialization_data=None,
       tracker_callback=None,
       upload_strategy=cloud_api.UploadStrategy.SIMPLE,
   ):
