@@ -260,11 +260,11 @@ class FlagTypes:
               "startupScript": arg_parsers.ArgObject(),
               "labels": LABEL,
               "bootDisk": self.GetProtoBootDiskType(),
-              "serviceAccount": SERVICE_ACCOUNT_TYPE,
               "startupScriptTimeout": str,
               "container-resource-labels": LABEL,
               "container-startup-script": arg_parsers.ArgObject(),
               "type": str,
+              "storageConfigs": STORAGE_CONFIG,
           },
           required_keys=["id"],
           enable_shorthand=True,
@@ -285,6 +285,7 @@ class FlagTypes:
                   },
                   enable_shorthand=True,
               ),
+              "storageConfigs": STORAGE_CONFIG,
           },
           required_keys=["id"],
           enable_shorthand=True,
@@ -294,7 +295,7 @@ class FlagTypes:
   def _GetSlurmPartitionSpec(self) -> dict[str, Any]:
     spec = {
         "id": str,
-        "nodesetIds": arg_parsers.ArgObject(value_type=str, repeated=True),
+        "nodeSetIds": arg_parsers.ArgObject(value_type=str, repeated=True),
     }
     if self.is_alpha:
       spec["exclusive"] = bool
@@ -303,7 +304,7 @@ class FlagTypes:
   def GetSlurmPartitionsObject(self) -> arg_parsers.ArgObject:
     return arg_parsers.ArgObject(
         spec=self._GetSlurmPartitionSpec(),
-        required_keys=["id", "nodesetIds"],
+        required_keys=["id", "nodeSetIds"],
         enable_shorthand=True,
         repeated=True,
     )
@@ -324,12 +325,12 @@ class FlagTypes:
               "machineType": str,
               "zone": str,
               "count": int,
-              "enableOSLogin": bool,
-              "enablePublicIPs": bool,
+              "enableOsLogin": bool,
+              "enablePublicIps": bool,
               "startupScript": arg_parsers.ArgObject(),
               "labels": LABEL,
               "bootDisk": self.GetProtoBootDiskType(),
-              "serviceAccount": SERVICE_ACCOUNT_TYPE,
+              "storageConfigs": STORAGE_CONFIG,
           },
           required_keys=["machineType", "zone"],
           enable_shorthand=True,
@@ -340,11 +341,12 @@ class FlagTypes:
               "machineType": str,
               "zone": str,
               "count": int,
-              "enableOSLogin": bool,
-              "enablePublicIPs": bool,
+              "enableOsLogin": bool,
+              "enablePublicIps": bool,
               "startupScript": str,
               "labels": LABEL,
               "bootDisk": self.GetProtoBootDiskType(),
+              "storageConfigs": STORAGE_CONFIG,
           },
           required_keys=["machineType", "zone"],
           enable_shorthand=True,
@@ -358,7 +360,6 @@ class FlagTypes:
               "count": int,
               "startupScript": arg_parsers.ArgObject(),
               "bootDisk": self.GetProtoBootDiskType(),
-              "serviceAccount": SERVICE_ACCOUNT_TYPE,
           },
           required_keys=[],
           enable_shorthand=True,
@@ -488,7 +489,6 @@ class FlagTypes:
                                   "storageConfigs": STORAGE_CONFIG,
                                   "zone": str,
                                   "bootDisk": self.GetProtoBootDiskType(),
-                                  "serviceAccount": SERVICE_ACCOUNT_TYPE,
                               }
                           ),
                           "nodeSets": arg_parsers.ArgObject(
@@ -498,7 +498,6 @@ class FlagTypes:
                                   "staticNodeCount": int,
                                   "storageConfigs": STORAGE_CONFIG,
                                   "computeId": str,
-                                  "serviceAccount": SERVICE_ACCOUNT_TYPE,
                                   "computeInstance": arg_parsers.ArgObject(
                                       spec={
                                           "startupScript": (
