@@ -16,9 +16,6 @@
 
 # TODO(b/331622809): Review and fix any violations of naming conventions.
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import ipaddress
 import re
@@ -343,18 +340,6 @@ def ValidateServiceMutexConfig(unused_ref, unused_args, req):
     BadArgumentException: when mutual exclusive configurations of service are
     set at the same time.
   """
-  if (
-      req.service.encryptionConfig
-      and (req.service.encryptionConfig.kmsKey or
-           req.service.encryptionConfig.kmsKeys)
-      and req.service.metadataIntegration.dataCatalogConfig.enabled
-  ):
-    raise exceptions.BadArgumentException(
-        '--data-catalog-sync',
-        'Data Catalog synchronization cannot be used in conjunction with'
-        ' customer-managed encryption keys.',
-    )
-
   return ValidateServiceMutexConfigForV1(unused_ref, unused_args, req)
 
 
@@ -381,16 +366,6 @@ def ValidateServiceMutexConfigForV1(unused_ref, unused_args, req):
         'Kerberos configuration cannot be used in conjunction with'
         ' --network-config-from-file or --consumer-subnetworks.',
     )
-  if (
-      req.service.encryptionConfig
-      and req.service.encryptionConfig.kmsKey
-      and req.service.metadataIntegration.dataCatalogConfig.enabled
-  ):
-    raise exceptions.BadArgumentException(
-        '--data-catalog-sync',
-        'Data Catalog synchronization cannot be used in conjunction with'
-        ' customer-managed encryption keys.',
-    )
   return req
 
 
