@@ -14,9 +14,6 @@
 # limitations under the License.
 """Flags and helpers for general Cloud NetApp Files commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 
 from googlecloudsdk.api_lib.netapp import constants
