@@ -16,10 +16,6 @@
 # pylint: disable=raise-missing-from
 """Pollers for Serverless operations."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.util import waiter
 from googlecloudsdk.command_lib.run import exceptions as serverless_exceptions
@@ -57,7 +53,12 @@ class ConditionPoller(waiter.OperationPoller):
   """
 
   def __init__(
-      self, resource_getter, tracker, dependencies=None, ready_message='Done.'
+      self,
+      resource_getter,
+      tracker,
+      dependencies=None,
+      ready_message='Done.',
+      skip_stage_updates=False,
   ):
     """Initialize the ConditionPoller.
 
@@ -80,6 +81,8 @@ class ConditionPoller(waiter.OperationPoller):
         dependencies.
       ready_message: str, message to display in header of tracker when
         conditions are ready.
+      skip_stage_updates: bool, if true, only the header message will be
+        updated.
     """
     # _dependencies is a map of condition -> {preceding conditions}
     # It is meant to be checked off as we finish things.
@@ -97,6 +100,7 @@ class ConditionPoller(waiter.OperationPoller):
     self._tracker = tracker
     self._resource_fail_type = exceptions.Error
     self._ready_message = ready_message
+    self._skip_stage_updates = skip_stage_updates
     self._StartUnblocked()
 
   def _IsBlocked(self, condition):
@@ -179,6 +183,8 @@ class ConditionPoller(waiter.OperationPoller):
       conditions_message: str, The message from the conditions object we're
         displaying..
     """
+    if self._skip_stage_updates:
+      return
     if condition not in self._tracker or self._tracker.IsComplete(condition):
       return
 
@@ -285,8 +291,17 @@ class ConditionPoller(waiter.OperationPoller):
 class ServiceConditionPoller(ConditionPoller):
   """A ConditionPoller for services."""
 
-  def __init__(self, getter, tracker, dependencies=None, serv=None):
-    super().__init__(getter, tracker, dependencies)
+  def __init__(
+      self,
+      getter,
+      tracker,
+      dependencies=None,
+      serv=None,
+      skip_stage_updates=False,
+  ):
+    super().__init__(
+        getter, tracker, dependencies, skip_stage_updates=skip_stage_updates
+    )
     self._resource_fail_type = serverless_exceptions.DeploymentFailedError
 
 
@@ -399,7 +414,7 @@ class WaitOperationPoller(waiter.CloudOperationPoller):
     """
     request_type = self.operation_service.GetRequestType('Wait')
     wait_req = self._messages_module.GoogleLongrunningWaitOperationRequest(
-        timeout='30s'
+        timeout='10s'
     )
     return self.operation_service.Wait(
         request_type(
