@@ -14,10 +14,6 @@
 # limitations under the License.
 """Shared resource flags for Cloud Run commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import abc
 import copy
