@@ -14,11 +14,7 @@
 # limitations under the License.
 """Class for representing various changes to a Cloud Run V2 resource."""
 
-from __future__ import absolute_import
 from __future__ import annotations
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
 
 import abc
 from collections.abc import Iterable, Mapping, Sequence
@@ -32,8 +28,8 @@ from googlecloudsdk.command_lib.run import config_changes
 from googlecloudsdk.command_lib.run import exceptions
 from googlecloudsdk.command_lib.run import flags
 from googlecloudsdk.command_lib.run import resource_name_conversion
+from googlecloudsdk.command_lib.run import volumes as volumes_lib
 from googlecloudsdk.command_lib.run.v2 import instance_split as instance_split_lib
-from googlecloudsdk.command_lib.run.v2 import volumes as volumes_lib
 from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import instance_split
 from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import k8s_min
 from googlecloudsdk.generated_clients.gapic_clients.run_v2.types import vendor_settings
@@ -593,6 +589,23 @@ class GpuTypeChange(config_changes.TemplateConfigChanger):
     return resource
 
 
+@dataclasses.dataclass(frozen=True)
+class GpuZonalRedundancyChange(config_changes.TemplateConfigChanger):
+  """Sets the gpu-zonal-redundancy-disabled field on the resource template.
+
+  Attributes:
+    gpu_zonal_redundancy: The gpu_zonal_redundancy value to set.
+  """
+
+  gpu_zonal_redundancy: bool
+
+  def Adjust(self, resource):
+    resource.template.gpu_zonal_redundancy_disabled = (
+        not self.gpu_zonal_redundancy
+    )
+    return resource
+
+
 @dataclasses.dataclass(init=False, frozen=True)
 class ContainerCommandChange(ContainerConfigChanger):
   """Represents the user intent to change the 'command' for the container.
@@ -1050,8 +1063,8 @@ class AddVolumeChange(config_changes.TemplateConfigChanger):
     current_volumes = {
         volume.name: volume for volume in resource.template.volumes
     }
-    for volume_dict in self.new_volumes:
-      new_volume = volumes_lib.CreateVolume(volume_dict, self.release_track)
+    for volume in self.new_volumes:
+      new_volume = volumes_lib.create_volume_v2(volume, self.release_track)
       current_volumes[new_volume.name] = new_volume
     resource.template.volumes = list(current_volumes.values())
     return resource
@@ -1191,109 +1204,35 @@ class ContainerDependenciesChange(config_changes.TemplateConfigChanger):
 
 # Worker pool specific config changes starts.
 @dataclasses.dataclass(frozen=True)
-class WorkerPoolScalingChange(config_changes.NonTemplateConfigChanger):
-  """Represents the user intent to adjust worker pool scaling.
+class WorkerPoolInstancesChange(config_changes.NonTemplateConfigChanger):
+  """Represents the user intent to adjust worker pool instances.
 
   Attributes:
-    min_instance_count: The minimum count of instances to set.
-    max_instance_count: The maximum count of instances to set.
-    scaling: Scaling flag value that either contains manual instance count or
-      auto scaling mode.
-    max_surge: Max surge to set.
-    max_unavailable: Max unavailable to set.
+    instances: Instances flag value that either contains manual instance count.
   """
 
-  min_instance_count: flags.ScaleValue | None = None
-  max_instance_count: flags.ScaleValue | None = None
-  scaling: flags.ScalingValue | None = None
-  max_surge: flags.MaxSurgeValue | None = None
-  max_unavailable: flags.MaxUnavailableValue | None = None
+  instances: flags.InstanceValue | None = None
 
   def Adjust(self, worker_pool_resource: worker_pool_objects.WorkerPool):
-    """Adjusts worker pool scaling.
+    """Adjusts worker pool instances.
 
     Args:
       worker_pool_resource: The worker pool resource to modify.
 
-    Raises:
-      ConfigurationError: If the user attempts to set min or max instance count
-      without setting --scaling=auto when the current scaling mode is manual.
-      ConfigurationError: If the user attempts to set min or max instance count
-      along with a manual instance count using --scaling flag.
-
     Returns:
       The adjusted worker pool resource.
     """
-    # Catch the case where user sets min or max without setting --scaling=auto
-    # when the current scaling mode is manual.
-    current_scaling_mode = worker_pool_resource.scaling.scaling_mode
-    if (
-        (self.min_instance_count or self.max_instance_count)
-        and not self.scaling
-        and current_scaling_mode
-        == vendor_settings.WorkerPoolScaling.ScalingMode.MANUAL
-    ):
-      raise exceptions.ConfigurationError(
-          'Need to specify --scaling=auto to swtich mode from manual to auto.'
-      )
-    # Min instance count
-    if self.min_instance_count:
-      if self.scaling and not self.scaling.auto_scaling:
-        raise exceptions.ConfigurationError(
-            'Cannot set --min when --scaling is set to a manual instance count.'
-        )
-      if self.min_instance_count.restore_default:
-        worker_pool_resource.scaling.min_instance_count = 1
-      else:
-        worker_pool_resource.scaling.min_instance_count = (
-            self.min_instance_count.instance_count
-        )
-    # Max instance count
-    if self.max_instance_count:
-      if self.scaling and not self.scaling.auto_scaling:
-        raise exceptions.ConfigurationError(
-            'Cannot set --max when --scaling is set to a manual instance count.'
-        )
-      if self.max_instance_count.restore_default:
-        worker_pool_resource.scaling.max_instance_count = 100
-      else:
-        worker_pool_resource.scaling.max_instance_count = (
-            self.max_instance_count.instance_count
-        )
     # Scaling mode & manual instance count
-    if self.scaling:
-      # Auto scaling mode
-      if self.scaling.auto_scaling:
-        # Remove manual instance count if auto scaling is set.
-        worker_pool_resource.scaling.manual_instance_count = None
-        worker_pool_resource.scaling.scaling_mode = (
-            vendor_settings.WorkerPoolScaling.ScalingMode.AUTOMATIC
-        )
-      # Manual scaling mode
-      else:
-        # Remove min and max instance count if manual instance count is set.
-        worker_pool_resource.scaling.min_instance_count = None
-        worker_pool_resource.scaling.max_instance_count = None
-        worker_pool_resource.scaling.scaling_mode = (
-            vendor_settings.WorkerPoolScaling.ScalingMode.MANUAL
-        )
-        worker_pool_resource.scaling.manual_instance_count = (
-            self.scaling.instance_count
-        )
-    # Max surge
-    if self.max_surge:
-      if self.max_surge.restore_default:
-        worker_pool_resource.scaling.max_surge = None
-      else:
-        worker_pool_resource.scaling.max_surge = self.max_surge.surge_percent
-    # Max unavailable
-    if self.max_unavailable:
-      if self.max_unavailable.restore_default:
-        worker_pool_resource.scaling.max_unavailable = None
-      else:
-        worker_pool_resource.scaling.max_unavailable = (
-            self.max_unavailable.unavailable_percent
-        )
+    if self.instances:
+      # Remove min and max instance count if manual instance count is set.
+      worker_pool_resource.scaling.min_instance_count = None
+      worker_pool_resource.scaling.max_instance_count = None
+      worker_pool_resource.scaling.scaling_mode = (
+          vendor_settings.WorkerPoolScaling.ScalingMode.MANUAL
+      )
+      worker_pool_resource.scaling.manual_instance_count = (
+          self.instances.instance_count
+      )
     return worker_pool_resource
 
 
