@@ -14,9 +14,6 @@
 # limitations under the License.
 """Common utility functions for sql instance commands."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import re
 
@@ -247,6 +244,14 @@ def _ParseServerCaMode(sql_messages, server_ca_mode):
   )
 
 
+def _ParseServerCertificateRotationMode(sql_messages, server_certificate_rotation_mode):
+  return (
+      sql_messages.IpConfiguration.ServerCertificateRotationModeValueValuesEnum.lookup_by_name(
+          server_certificate_rotation_mode.upper()
+      )
+  )
+
+
 # TODO(b/122660263): Remove when V1 instances are no longer supported.
 def ShowV1DeprecationWarning(plural=False):
   message = (
@@ -548,6 +553,15 @@ class _BaseInstances(object):
           ),
       )
 
+    if args.IsKnownAndSpecified('server_certificate_rotation_mode'):
+      if not settings.ipConfiguration:
+        settings.ipConfiguration = sql_messages.IpConfiguration()
+      settings.ipConfiguration.serverCertificateRotationMode = (
+          _ParseServerCertificateRotationMode(
+              sql_messages, args.server_certificate_rotation_mode
+          )
+      )
+
     if args.IsKnownAndSpecified('custom_subject_alternative_names'):
       if not settings.ipConfiguration:
         settings.ipConfiguration = sql_messages.IpConfiguration()
@@ -560,13 +574,13 @@ class _BaseInstances(object):
         settings.ipConfiguration = sql_messages.IpConfiguration()
       settings.ipConfiguration.customSubjectAlternativeNames = []
 
+    if args.IsKnownAndSpecified('data_api_access'):
+      settings.dataApiAccess = _ParseDataApiAccess(
+          sql_messages, args.data_api_access
+      )
+
     # BETA args.
     if IsBetaOrNewer(release_track):
-      if args.IsSpecified('data_api_access'):
-        settings.dataApiAccess = _ParseDataApiAccess(
-            sql_messages, args.data_api_access
-        )
-
       if args.IsSpecified('storage_auto_increase_limit'):
         # Resize limit should be settable if the original instance has resize
         # turned on, or if the instance to be created has resize flag.
@@ -709,6 +723,15 @@ class _BaseInstances(object):
     if args.time_zone is not None:
       settings.timeZone = args.time_zone
 
+    if args.IsKnownAndSpecified(
+        'entra_id_tenant_id'
+    ) or args.IsKnownAndSpecified('entra_id_application_id'):
+      settings.entraidConfig = reducers.SqlServerEntraIdConfig(
+          sql_messages,
+          args.entra_id_tenant_id,
+          args.entra_id_application_id,
+      )
+
     if (
         args.IsKnownAndSpecified('threads_per_core')
         and args.threads_per_core is not None
@@ -778,6 +801,21 @@ class _BaseInstances(object):
       if db_aligned_atomic_writes_config is not None:
         settings.dbAlignedAtomicWritesConfig = db_aligned_atomic_writes_config
 
+      if args.IsKnownAndSpecified('performance_capture_config'):
+        performance_capture_config = reducers.PerformanceCaptureConfig(
+            sql_messages,
+            performance_capture_config=args.performance_capture_config,
+            current_config=None,
+        )
+        if performance_capture_config is not None:
+          settings.performanceCaptureConfig = performance_capture_config
+
+      if args.IsKnownAndSpecified('unc_mappings'):
+        settings.uncMappings = reducers.UncMappings(
+            sql_messages,
+            unc_mappings=args.unc_mappings,
+        )
+
     return settings
 
   @classmethod
@@ -860,6 +898,11 @@ class _BaseInstances(object):
           )
       )
 
+    if args.storage_type:
+      settings.dataDiskType = _ParseStorageType(
+          sql_messages, STORAGE_TYPE_MAPPING.get(args.storage_type)
+      )
+
     settings.insightsConfig = reducers.InsightsConfig(
         sql_messages,
         insights_config_query_insights_enabled=args.insights_config_query_insights_enabled,
@@ -902,6 +945,18 @@ class _BaseInstances(object):
     if args.time_zone is not None:
       settings.timeZone = args.time_zone
 
+    if (
+        args.IsKnownAndSpecified('entra_id_tenant_id')
+        or args.IsKnownAndSpecified('entra_id_application_id')
+        or args.IsKnownAndSpecified('clear_entra_id_config')
+    ):
+      settings.entraidConfig = reducers.SqlServerEntraIdConfig(
+          sql_messages,
+          args.entra_id_tenant_id,
+          args.entra_id_application_id,
+          args.clear_entra_id_config,
+      )
+
     final_backup_configuration = reducers.FinalBackupConfiguration(
         sql_messages,
         instance,
@@ -973,6 +1028,16 @@ class _BaseInstances(object):
             unc_mappings=args.unc_mappings,
             clear_unc_mappings=args.clear_unc_mappings,
         )
+
+      if args.IsKnownAndSpecified('performance_capture_config'):
+        performance_capture_config = reducers.PerformanceCaptureConfig(
+            sql_messages,
+            performance_capture_config=args.performance_capture_config,
+            current_config=original_settings.performanceCaptureConfig,
+        )
+        if performance_capture_config is not None:
+          settings.performanceCaptureConfig = performance_capture_config
+
     # ALPHA args.
     if _IsAlpha(release_track):
       pass
