@@ -14,9 +14,6 @@
 # limitations under the License.
 """Task iterator for copy functionality."""
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import unicode_literals
 
 import os
 
@@ -263,7 +260,7 @@ def _destination_is_container(destination):
   destination_url = destination.storage_url
   if isinstance(destination_url, storage_url.FileUrl):
     # We don't want to treat non-existing file paths as valid containers.
-    return os.path.isdir(destination_url.object_name)
+    return os.path.isdir(destination_url.resource_name)
 
   return (destination_url.versionless_url_string.endswith(
       destination_url.delimiter) or
@@ -430,14 +427,14 @@ class CopyTaskIterator:
       raise errors.InvalidUrlError(
           'Destination URL must name an existing directory.'
           ' Provided: {}.'.format(
-              self._raw_destination.storage_url.object_name))
+              self._raw_destination.storage_url.resource_name))
 
   def _raise_if_download_destination_ends_with_delimiter_and_does_not_exist(
       self,
   ):
     if isinstance(self._raw_destination.storage_url, storage_url.FileUrl):
       # Download operation.
-      destination_path = self._raw_destination.storage_url.object_name
+      destination_path = self._raw_destination.storage_url.resource_name
       if destination_path.endswith(
           self._raw_destination.storage_url.delimiter
       ) and not self._raw_destination.storage_url.isdir():
@@ -533,6 +530,23 @@ class CopyTaskIterator:
           source_url, destination_url
       )
 
+      should_skip_file_download = (
+          copy_util.should_skip_file_download_if_outside_destination(
+              source_url,
+              source.expanded_url,
+              destination_url,
+              self._raw_destination.storage_url,
+          )
+      )
+      if should_skip_file_download:
+        message = (
+            f'Skipping copy of source URL {source_url} because it would'
+            ' be copied outside the expected destination directory:'
+            f' {self._raw_destination.storage_url.resource_name}.'
+        )
+        self._print_skip_and_maybe_send_to_manifest(message, source)
+        continue
+
       if (
           self._folders_only
           and self._delete_source
@@ -552,7 +566,7 @@ class CopyTaskIterator:
       )
       if (isinstance(source.resource, resource_reference.ObjectResource) and
           isinstance(destination_url, storage_url.FileUrl) and
-          destination_url.object_name.endswith(destination_url.delimiter)):
+          destination_url.resource_name.endswith(destination_url.delimiter)):
         log.debug('Skipping downloading {} to {} since the destination ends in'
                   ' a file system delimiter.'.format(
                       source_url.versionless_url_string,
