@@ -14,10 +14,7 @@
 # limitations under the License.
 """Utils for generating API-specific RequestConfig objects."""
 
-from __future__ import absolute_import
 from __future__ import annotations
-from __future__ import division
-from __future__ import unicode_literals
 
 import collections
 import enum
@@ -109,6 +106,7 @@ class _UserBucketArgs(_UserResourceArgs):
       enable_autoclass=None,
       enable_per_object_retention=None,
       enable_hierarchical_namespace=None,
+      encryption_enforcement_file_path=None,
       ip_filter_file_path=None,
       labels_file_path=None,
       labels_to_append=None,
@@ -146,6 +144,7 @@ class _UserBucketArgs(_UserResourceArgs):
     self.enable_autoclass = enable_autoclass
     self.enable_per_object_retention = enable_per_object_retention
     self.enable_hierarchical_namespace = enable_hierarchical_namespace
+    self.encryption_enforcement_file_path = encryption_enforcement_file_path
     self.ip_filter_file_path = ip_filter_file_path
     self.labels_file_path = labels_file_path
     self.labels_to_append = labels_to_append
@@ -188,6 +187,8 @@ class _UserBucketArgs(_UserResourceArgs):
         == other.enable_per_object_retention
         and self.enable_hierarchical_namespace
         == other.enable_hierarchical_namespace
+        and self.encryption_enforcement_file_path
+        == other.encryption_enforcement_file_path
         and self.ip_filter_file_path == other.ip_filter_file_path
         and self.labels_file_path == other.labels_file_path
         and self.labels_to_append == other.labels_to_append
@@ -416,6 +417,9 @@ def get_user_request_args_from_command_args(args, metadata_type=None):
           ),
           cors_file_path=cors_file_path,
           default_encryption_key=default_encryption_key,
+          encryption_enforcement_file_path=getattr(
+              args, 'encryption_enforcement_file', None
+          ),
           default_event_based_hold=getattr(
               args, 'default_event_based_hold', None
           ),
