@@ -25,9 +25,9 @@ from googlecloudsdk.core.util import files
 from googlecloudsdk.core.util import platforms
 
 
-PYTHON_VERSION = '3.12'
-PYTHON_VERSION_INFO = (3, 12)
-MACOS_PYTHON = 'python-3.12.8-macos11.tar.gz'
+PYTHON_VERSION = '3.13'
+PYTHON_VERSION_INFO = (3, 13)
+MACOS_PYTHON = 'python-3.13.7-macos11.tar.gz'
 
 HOMEBREW_BIN = '/opt/homebrew/bin'
 MACOS_PYTHON_INSTALL_PATH = (
@@ -89,17 +89,8 @@ def _IsHomebrewInstalled():
   return os.path.isdir(HOMEBREW_BIN) and 'homebrew' in config.GcloudPath()
 
 
-def _PromptPythonUpdate(python_install_path):
-  return (
-      f'(Recommended) Python {PYTHON_VERSION} installation detected in '
-      f'{python_install_path}, install required modules (Y/n)?')
-
-
 def _PromptPythonInstall():
-  if _IsHomebrewInstalled():
-    return f'Homebrew install Python {PYTHON_VERSION}?'
-  else:
-    return f'Download and run Python {PYTHON_VERSION} installer?'
+  return f'Download and run Python {PYTHON_VERSION} installer?'
 
 
 def _BrewInstallPython():
@@ -122,7 +113,9 @@ def _MacInstallPython():
         'sudo password...')
 
   # Xcode Command Line Tools is required to install Python.
-  PromptAndInstallXcodeCommandLineTools()
+  install_error = InstallXcodeCommandLineTools()
+  if install_error:
+    return install_error
 
   with files.TemporaryDirectory() as tempdir:
     with files.ChDir(tempdir):
@@ -138,7 +131,7 @@ def _MacInstallPython():
 
       exit_code = execution_utils.Exec([
           'sudo', 'installer', '-target', '/', '-pkg',
-          './python-3.12.8-macos11.pkg'
+          './python-3.13.7-macos11.pkg'
       ], no_exit=True)
       if exit_code != 0:
         return 'Installer failed.'
@@ -164,20 +157,16 @@ def PromptAndInstallPythonOnMac():
     python_to_use = f'{MACOS_PYTHON_INSTALL_PATH}bin/python3'
   already_installed = os.path.isfile(python_to_use)
 
-  # Prompt for user permission
-  if already_installed:
-    prompt = _PromptPythonUpdate(python_to_use)
-  else:
-    prompt = _PromptPythonInstall()
-  if not console_io.PromptContinue(prompt_string=prompt, default=True):
-    return
-
-  # Install python if needed
+  install_errors = None
   if not already_installed:
-    install_errors = (_BrewInstallPython()
-                      if homebrew_installed else _MacInstallPython())
-  else:
-    install_errors = None
+    if homebrew_installed:
+      install_errors = _BrewInstallPython()
+    else:
+      # Prompt for user permission to install python if not already installed
+      prompt = _PromptPythonInstall()
+      if not console_io.PromptContinue(prompt_string=prompt, default=True):
+        return
+      install_errors = _MacInstallPython()
 
   # Update python dependencies
   if not install_errors:
@@ -194,28 +183,25 @@ def CheckXcodeCommandLineToolsInstalled() -> bool:
   return exit_code == 0
 
 
-def PromptAndInstallXcodeCommandLineTools():
+def InstallXcodeCommandLineTools() -> str | None:
   """Optionally install Xcode Command Line Tools on Mac machines."""
   if platforms.OperatingSystem.Current() != platforms.OperatingSystem.MACOSX:
-    return
+    return None
 
   if CheckXcodeCommandLineToolsInstalled():
     print('Xcode Command Line Tools is already installed.')
-    return
+    return None
 
-  prompt = (
-      'Xcode Command Line Tools is required to install Python. Continue to'
-      ' install (Y/n)?'
-  )
-  setup_xcode = console_io.PromptContinue(prompt_string=prompt, default=True)
+  print('Installing Xcode Command Line Tools, which is '
+        'required to install Python...')
+  xcode_command = ['xcode-select', '--install']
+  exit_code = execution_utils.Exec(xcode_command, no_exit=True)
+  if exit_code != 0:
+    print('Failed to install Xcode Command Line Tools. '
+          'Please run `xcode-select --install` manually to install '
+          'Xcode Command Line Tools.')
+    return 'Failed to install Xcode Command Line Tools.'
+  else:
+    print('Xcode Command Line Tools is installed.')
 
-  if setup_xcode:
-    print('Installing Xcode Command Line Tools...')
-    xcode_command = ['xcode-select', '--install']
-    exit_code = execution_utils.Exec(xcode_command, no_exit=True)
-    if exit_code != 0:
-      print('Failed to install Xcode Command Line Tools. '
-            'Please run `xcode-select --install` manually to install '
-            'Xcode Command Line Tools.')
-    else:
-      print('Xcode Command Line Tools is installed.')
+  return None
