@@ -25,6 +25,7 @@ from apitools.base.py import exceptions as apitools_exceptions
 from googlecloudsdk.api_lib.compute import metadata_utils
 from googlecloudsdk.api_lib.compute import utils
 from googlecloudsdk.api_lib.container import api_adapter
+from googlecloudsdk.api_lib.container import constants as api_constants
 from googlecloudsdk.api_lib.container import kubeconfig as kconfig
 from googlecloudsdk.api_lib.container import util
 from googlecloudsdk.api_lib.functions import api_enablement
@@ -241,11 +242,18 @@ def ParseCreateOptionsBase(
       addons = {api_adapter.RAYOPERATOR: True}
     else:
       addons[api_adapter.RAYOPERATOR] = True
+  if getattr(args, 'enable_slurm_operator', None):
+    if addons is None:
+      addons = {api_adapter.SLURMOPERATOR: True}
+    else:
+      addons[api_adapter.SLURMOPERATOR] = True
   if getattr(args, 'enable_lustre_csi_driver', None):
     if addons is None:
       addons = {api_adapter.LUSTRECSIDRIVER: True}
     else:
       addons[api_adapter.LUSTRECSIDRIVER] = True
+  enable_pod_snapshots = get_default('pod_snapshots_enabled')
+  enable_agent_sandbox = get_default('enable_agent_sandbox')
 
   return api_adapter.CreateClusterOptions(
       accelerators=get_default('accelerator'),
@@ -279,6 +287,7 @@ def ParseCreateOptionsBase(
       dataplane_v2_observability_mode=get_default(
           'dataplane_v2_observability_mode'
       ),
+      enable_ambient_networking=get_default('enable_ambient_networking'),
       disk_type=get_default('disk_type'),
       enable_autorepair=enable_autorepair,
       enable_autoscaling=get_default('enable_autoscaling'),
@@ -317,6 +326,7 @@ def ParseCreateOptionsBase(
       ),
       enable_legacy_authorization=get_default('enable_legacy_authorization'),
       enable_managed_prometheus=get_default('enable_managed_prometheus'),
+      enable_managed_mldiagnostics=get_default('enable_managed_mldiagnostics'),
       auto_monitoring_scope=get_default('auto_monitoring_scope'),
       enable_master_authorized_networks=get_default(
           'enable_master_authorized_networks'
@@ -338,6 +348,12 @@ def ParseCreateOptionsBase(
       labels=get_default('labels'),
       local_nvme_ssd_block=(local_nvme_ssd_block),
       local_ssd_count=get_default('local_ssd_count'),
+      maintenance_minor_version_disruption_interval=get_default(
+          'maintenance_minor_version_disruption_interval'
+      ),
+      maintenance_patch_version_disruption_interval=get_default(
+          'maintenance_patch_version_disruption_interval'
+      ),
       maintenance_window=get_default('maintenance_window'),
       maintenance_window_start=get_default('maintenance_window_start'),
       maintenance_window_end=get_default('maintenance_window_end'),
@@ -503,7 +519,11 @@ def ParseCreateOptionsBase(
           'enable_runtime_vulnerability_insight'
       ),
       workload_policies=get_default('workload_policies'),
+      autopilot_cluster_policies=get_default('autopilot_cluster_policies'),
       in_transit_encryption=get_default('in_transit_encryption'),
+      enable_kernel_module_signature_enforcement=get_default(
+          'enable_kernel_module_signature_enforcement'
+      ),
       containerd_config_from_file=get_default('containerd_config_from_file'),
       fleet_project=get_default('fleet_project'),
       enable_fleet=get_default('enable_fleet'),
@@ -569,6 +589,10 @@ def ParseCreateOptionsBase(
       enable_auto_ipam=get_default('enable_auto_ipam'),
       enable_k8s_tokens_via_dns=get_default('enable_k8s_tokens_via_dns'),
       enable_legacy_lustre_port=get_default('enable_legacy_lustre_port'),
+      disable_multi_nic_lustre=get_default('disable_multi_nic_lustre'),
+      enable_lustre_multi_nic=get_default('enable_lustre_multi_nic'),
+      enable_pod_snapshots=enable_pod_snapshots,
+      enable_agent_sandbox=enable_agent_sandbox,
       enable_default_compute_class=get_default('enable_default_compute_class'),
       enable_k8s_certs_via_dns=get_default('enable_k8s_certs_via_dns'),
       boot_disk_provisioned_iops=get_default('boot_disk_provisioned_iops'),
@@ -577,8 +601,14 @@ def ParseCreateOptionsBase(
       ),
       network_tier=get_default('network_tier'),
       control_plane_egress_mode=get_default('control_plane_egress'),
+      enable_slice_controller=get_default('enable_slice_controller'),
+      autopilot_general_profile=get_default('autopilot_general_profile'),
+      node_architecture_taint_behavior=get_default(
+          'node_architecture_taint_behavior'
+      ),
   )
 
+
 GA = 'ga'
 BETA = 'beta'
 ALPHA = 'alpha'
@@ -669,6 +699,9 @@ flags_to_add = {
         'hpaprofile': flags.AddHPAProfilesFlag,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'args': _Args,
         'basicauth': flags.AddBasicAuthFlags,
@@ -717,6 +750,9 @@ flags_to_add = {
         'logging': flags.AddLoggingFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=False)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -728,6 +764,7 @@ flags_to_add = {
         'maxnodes': flags.AddMaxNodesPerPool,
         'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maxunavailable': flags.AddMaxUnavailableUpgradeFlag,
+        'membershipType': flags.AddMembershipTypeFlags,
         'meshcertificates': flags.AddMeshCertificatesFlags,
         'metadata': flags.AddMetadataFlags,
         'mincpu': flags.AddMinCpuPlatformFlag,
@@ -737,6 +774,9 @@ flags_to_add = {
         'nodelabels': flags.AddNodeLabelsFlag,
         'nodelocations': flags.AddNodeLocationsFlag,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeversion': flags.AddNodeVersionFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
         'num_nodes': flags.AddNumNodes,
@@ -800,6 +840,9 @@ flags_to_add = {
         ),
         'containerdConfig': flags.AddContainerdConfigFlag,
         'secretManagerConfig': flags.AddSecretManagerEnableFlagGroup,
+        'secretSyncConfig': lambda p: flags.AddSecretSyncFlagGroup(
+            p, hidden=True
+        ),
         'InTransitEncryption': flags.AddInTransitEncryptionFlag,
         'enableCiliumClusterwideNetworkPolicy': (
             flags.AddEnableCiliumClusterwideNetworkPolicyFlag
@@ -832,6 +875,10 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
@@ -839,6 +886,13 @@ flags_to_add = {
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
+        'enableKernelModuleSignatureEnforcement': (
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
     },
     BETA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -852,6 +906,9 @@ flags_to_add = {
         'authenticatorsecurity': flags.AddAuthenticatorSecurityGroupFlags,
         'autoupgrade': AddEnableAutoUpgradeWithDefault,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'basicauth': flags.AddBasicAuthFlags,
         'binauthz': lambda p: flags.AddBinauthzFlags(
             p, release_track=base.ReleaseTrack.BETA
@@ -906,6 +963,9 @@ flags_to_add = {
         'legacyauth': flags.AddEnableLegacyAuthorizationFlag,
         'machinetype': flags.AddMachineTypeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=False)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -930,10 +990,18 @@ flags_to_add = {
         ),
         'networkpolicy': flags.AddNetworkPolicyFlags,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeidentity': flags.AddClusterNodeIdentityFlags,
         'nodeversion': flags.AddNodeVersionFlag,
         'nodelabels': flags.AddNodeLabelsFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
+        'nodepoolupgradeconcurrencyconfig': (
+            lambda p: flags.AddNodePoolUpgradeConcurrencyConfigFlag(
+                p, hidden=True
+            )
+        ),
         'num_nodes': flags.AddNumNodes,
         'performancemonitoringunit': (
             lambda p: flags.AddPerformanceMonitoringUnit(p, hidden=False)
@@ -1039,16 +1107,35 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
+            p, hidden=False
+        ),
+        'managedMLDiagnostics': lambda p: flags.AddManagedMLDiagnosticsFlags(
             p, hidden=True
         ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
+        'podsnapshots': flags.AddPodSnapshotConfigFlags,
+        'agentsandbox': flags.AddAgentSandboxConfigFlags,
+        'enableKernelModuleSignatureEnforcement': (
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
+        'linkedRunnersMode': lambda p: flags.AddLinkedRunnersModeFlag(
+            p, hidden=True
+        ),
     },
     ALPHA: {
         'accelerator': lambda p: AddAcceleratorFlag(p, True, True, True, True),
@@ -1061,6 +1148,9 @@ flags_to_add = {
         'autorepair': AddAutoRepair,
         'autoscalingprofiles': flags.AddAutoscalingProfilesFlag,
         'autopilotworkloadpolicies': flags.AddAutopilotWorkloadPoliciesFlag,
+        'autopilotclusterpolicies': (
+            lambda p: flags.AddAutopilotClusterPoliciesFlag(p, hidden=True)
+        ),
         'hpaprofile': flags.AddHPAProfilesFlag,
         'basicauth': flags.AddBasicAuthFlags,
         'cloudlogging': flags.AddEnableCloudLogging,
@@ -1089,6 +1179,7 @@ flags_to_add = {
         'dataplanev2': flags.AddDataplaneV2Flag,
         'dataplanev2metrics': flags.AddDataplaneV2MetricsFlag,
         'dataplanev2obs': flags.AddDataplaneV2ObservabilityFlags,
+        'enableAmbientNetworking': flags.AddEnableAmbientNetworkingFlag,
         'disabledefaultsnat': AddDisableDefaultSnatFlagForClusterCreate,
         'disksize': flags.AddDiskSizeFlag,
         'disktype': flags.AddDiskTypeFlag,
@@ -1128,6 +1219,9 @@ flags_to_add = {
         'maxnodes': flags.AddMaxNodesPerPool,
         'maxpodspernode': flags.AddMaxPodsPerNodeFlag,
         'maintenancewindow': flags.AddMaintenanceWindowGroup,
+        'maintenancedisruptionbudget': lambda p: (
+            flags.AddMaintenanceDisruptionBudgetFlagGroup(p, hidden=False)
+        ),
         'managedprometheus': lambda p: flags.AddManagedPrometheusFlags(
             p, for_create=True
         ),
@@ -1143,10 +1237,18 @@ flags_to_add = {
         'monitoring': flags.AddMonitoringFlag,
         'networkpolicy': flags.AddNetworkPolicyFlags,
         'nodetaints': flags.AddNodeTaintsFlag,
+        'nodearchitecturetaintbehavior': (
+            flags.AddNodeArchitectureTaintBehaviorFlag
+        ),
         'nodeidentity': flags.AddClusterNodeIdentityFlags,
         'nodeversion': flags.AddNodeVersionFlag,
         'nodelabels': flags.AddNodeLabelsFlag,
         'notificationconfig': flags.AddNotificationConfigFlag,
+        'nodepoolupgradeconcurrencyconfig': (
+            lambda p: flags.AddNodePoolUpgradeConcurrencyConfigFlag(
+                p, hidden=True
+            )
+        ),
         'num_nodes': flags.AddNumNodes,
         'performancemonitoringunit': (
             lambda p: flags.AddPerformanceMonitoringUnit(p, hidden=False)
@@ -1255,16 +1357,35 @@ flags_to_add = {
         'enableAutoIpam': flags.AddAutoIpamFlag,
         'enableK8sTokensViaDns': flags.AddEnableK8sTokensViaDnsFlag,
         'enableLegacyLustrePort': flags.AddEnableLegacyLustrePortFlag,
+        'disableMultiNicLustre': flags.AddDisableMultiNicLustreFlag,
         'enableDefaultComputeClass': flags.AddEnableDefaultComputeClassFlag,
         'enableK8sCertsViaDns': flags.AddEnableK8sCertsViaDnsFlag,
         'networkTier': flags.AddNetworkTierFlag,
         'controlPlaneEgress': flags.AddControlPlaneEgressFlag,
         'managedOTelScope': lambda p: flags.AddManagedOTelScopeFlags(
+            p, hidden=False
+        ),
+        'managedMLDiagnostics': lambda p: flags.AddManagedMLDiagnosticsFlags(
             p, hidden=True
         ),
         'autopilotPrivilegedAdmission': (
             lambda p: flags.AddAutopilotPrivilegedAdmissionFlag(p, hidden=True)
         ),
+        'podsnapshots': flags.AddPodSnapshotConfigFlags,
+        'agentsandbox': flags.AddAgentSandboxConfigFlags,
+        'enableKernelModuleSignatureEnforcement': (
+            flags.AddEnableKernelModuleSignatureEnforcementFlag
+        ),
+        'enableLustreMultiNic': lambda p: flags.AddEnableLustreMultiRailFlag(
+            p, hidden=True
+        ),
+        'enableSliceController': lambda p: flags.AddEnableSliceControllerFlag(
+            p, hidden=True
+        ),
+        'autopilotGeneralProfile': flags.AddAutopilotGeneralProfileFlag,
+        'linkedRunnersMode': lambda p: flags.AddLinkedRunnersModeFlag(
+            p, hidden=True
+        ),
     },
 }
 # LINT.ThenChange(create_auto.py:auto_flags)
@@ -1358,7 +1479,16 @@ class Create(base.CreateCommand):
           'https://cloud.google.com/kubernetes-engine/docs/how-to/private-clusters'
       )
 
-    if not options.enable_ip_alias and not options.enable_auto_ipam:
+    is_cluster_ipv6 = (
+        options.stack_type
+        and options.stack_type.lower() == api_constants.IPV6_STACK_TYPE
+    )
+
+    if (
+        not options.enable_ip_alias
+        and not options.enable_auto_ipam
+        and not is_cluster_ipv6
+    ):
       max_node_number = util.CalculateMaxNodeNumberByPodRange(
           options.cluster_ipv4_cidr
       )
@@ -1510,6 +1640,9 @@ class CreateBeta(Create):
     ops.enable_experimental_vertical_pod_autoscaling = get_default(
         'enable_experimental_vertical_pod_autoscaling'
     )
+    ops.node_pool_upgrade_concurrency_config = get_default(
+        'node_pool_upgrade_concurrency_config'
+    )
     ops.security_group = get_default('security_group')
     ops.max_surge_upgrade = get_default('max_surge_upgrade')
     ops.max_unavailable_upgrade = get_default('max_unavailable_upgrade')
@@ -1547,6 +1680,9 @@ class CreateBeta(Create):
         get_default('cross_connect_subnetworks'))
     ops.enable_service_externalips = get_default('enable_service_externalips')
     ops.enable_managed_prometheus = get_default('enable_managed_prometheus')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     ops.auto_monitoring_scope = get_default('auto_monitoring_scope')
     ops.spot = get_default('spot')
     ops.maintenance_interval = get_default('maintenance_interval')
@@ -1620,6 +1756,7 @@ class CreateBeta(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1627,6 +1764,10 @@ class CreateBeta(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
+    ops.linked_runners_mode = get_default('linked_runners_mode')
     return ops
 
 
@@ -1713,6 +1854,9 @@ class CreateAlpha(Create):
         get_default('cross_connect_subnetworks'))
     ops.enable_service_externalips = get_default('enable_service_externalips')
     ops.enable_managed_prometheus = get_default('enable_managed_prometheus')
+    ops.enable_managed_mldiagnostics = get_default(
+        'enable_managed_mldiagnostics'
+    )
     ops.auto_monitoring_scope = get_default('auto_monitoring_scope')
     ops.spot = get_default('spot')
     ops.maintenance_interval = get_default('maintenance_interval')
@@ -1744,6 +1888,9 @@ class CreateAlpha(Create):
     ops.enable_runtime_vulnerability_insight = get_default(
         'enable_runtime_vulnerability_insight'
     )
+    ops.node_pool_upgrade_concurrency_config = get_default(
+        'node_pool_upgrade_concurrency_config'
+    )
     ops.patch_update = get_default('patch_update')
     ops.host_maintenance_interval = get_default('host_maintenance_interval')
     ops.contianerd_config_from_file = get_default('contianerd_config_from_file')
@@ -1783,6 +1930,7 @@ class CreateAlpha(Create):
     ops.enable_auto_ipam = get_default('enable_auto_ipam')
     ops.enable_k8s_tokens_via_dns = get_default('enable_k8s_tokens_via_dns')
     ops.enable_legacy_lustre_port = get_default('enable_legacy_lustre_port')
+    ops.disable_multi_nic_lustre = get_default('disable_multi_nic_lustre')
     ops.enable_default_compute_class = get_default(
         'enable_default_compute_class'
     )
@@ -1790,4 +1938,6 @@ class CreateAlpha(Create):
     ops.control_plane_egress_mode = get_default('control_plane_egress')
     ops.gpudirect_strategy = get_default('gpudirect_strategy')
     ops.managed_otel_scope = get_default('managed_otel_scope')
+    ops.autopilot_general_profile = get_default('autopilot_general_profile')
+    ops.linked_runners_mode = get_default('linked_runners_mode')
     return ops
